jsonpointer: Identify specific nodes in a JSON document (RFC 6901)
==================================================================

Description
-----------

Identify specific nodes in a JSON document (RFC 6901)

License
-------

Modified BSD License

Upstream Contact
----------------

https://pypi.org/project/jsonpointer/

